==> estateplat-common-1.2.4-20190527.015517-166-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtSjcl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 * 收件材料配置
 *
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version V1.0, 15-3-19
 */
@Table(name = "bdc_xt_sjcl")
public class BdcXtSjcl implements Serializable {
    @Id
    public String sjclid; //收件材料id
    public String clmc;//材料名称
    public String sqlx;//申请类型
    public String cllx;//材料类型
    public Integer mrfs;//默认份数
    public String djzx;//登记子项
    public Integer xh;//序号
    public String dwdm;//单位代码
    private Integer yjfs;//原件份数

    private Integer fyjfs;//复印件份数

    private Integer gxfs;//共享份数

    private String  sfys;//是否验收

    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public Integer getMrfs() {
        return mrfs;
    }

    public void setMrfs(Integer mrfs) {
        this.mrfs = mrfs;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public Integer getYjfs() {
        return yjfs;
    }

    public void setYjfs(Integer yjfs) {
        this.yjfs = yjfs;
    }

    public Integer getFyjfs() {
        return fyjfs;
    }

    public void setFyjfs(Integer fyjfs) {
        this.fyjfs = fyjfs;
    }

    public Integer getGxfs() {
        return gxfs;
    }

    public void setGxfs(Integer gxfs) {
        this.gxfs = gxfs;
    }

    public String getSfys() {
        return sfys;
    }

    public void setSfys(String sfys) {
        this.sfys = sfys;
    }
}

==> estateplat-common-1.2.4-20201012.021241-460-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtSjcl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * .
 * <p/>
 * 收件材料配置
 *
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version V1.0, 15-3-19
 */
@Table(name = "bdc_xt_sjcl")
public class BdcXtSjcl implements Serializable {
    @Id
    public String sjclid; //收件材料id
    public String clmc;//材料名称
    public String sqlx;//申请类型
    public String cllx;//材料类型
    public Integer mrfs;//默认份数
    public String djzx;//登记子项
    public Integer xh;//序号
    public String dwdm;//单位代码
    private Integer yjfs;//原件份数

    private Integer fyjfs;//复印件份数

    private Integer gxfs;//共享份数

    private String sfys;//是否验收
    private String clly; //材料来源


    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public Integer getMrfs() {
        return mrfs;
    }

    public void setMrfs(Integer mrfs) {
        this.mrfs = mrfs;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public Integer getYjfs() {
        return yjfs;
    }

    public void setYjfs(Integer yjfs) {
        this.yjfs = yjfs;
    }

    public Integer getFyjfs() {
        return fyjfs;
    }

    public void setFyjfs(Integer fyjfs) {
        this.fyjfs = fyjfs;
    }

    public Integer getGxfs() {
        return gxfs;
    }

    public void setGxfs(Integer gxfs) {
        this.gxfs = gxfs;
    }

    public String getSfys() {
        return sfys;
    }

    public void setSfys(String sfys) {
        this.sfys = sfys;
    }

    public String getClly() {
        return clly;
    }

    public void setClly(String clly) {
        this.clly = clly;
    }
}
